@@ -4,7 +4,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '2.1.99'
+__version__ = '2.2.17'
 
 # ----------------------------------------------------------------------------
 
@@ -31,6 +31,7 @@ from ccxt.pro.bitstamp import bitstamp                                    # noqa
 from ccxt.pro.bittrex import bittrex                                      # noqa: F401
 from ccxt.pro.bitvavo import bitvavo                                      # noqa: F401
 from ccxt.pro.bybit import bybit                                          # noqa: F401
+from ccxt.pro.cex import cex                                              # noqa: F401
 from ccxt.pro.coinbaseprime import coinbaseprime                          # noqa: F401
 from ccxt.pro.coinbasepro import coinbasepro                              # noqa: F401
 from ccxt.pro.coinex import coinex                                        # noqa: F401
@@ -48,6 +49,7 @@ from ccxt.pro.huobipro import huobipro                                    # noqa
 from ccxt.pro.idex import idex                                            # noqa: F401
 from ccxt.pro.kraken import kraken                                        # noqa: F401
 from ccxt.pro.kucoin import kucoin                                        # noqa: F401
+from ccxt.pro.luno import luno                                            # noqa: F401
 from ccxt.pro.mexc import mexc                                            # noqa: F401
 from ccxt.pro.ndax import ndax                                            # noqa: F401
 from ccxt.pro.okcoin import okcoin                                        # noqa: F401
@@ -78,6 +80,7 @@ exchanges = [
     'bittrex',
     'bitvavo',
     'bybit',
+    'cex',
     'coinbaseprime',
     'coinbasepro',
     'coinex',
@@ -95,6 +98,7 @@ exchanges = [
     'idex',
     'kraken',
     'kucoin',
+    'luno',
     'mexc',
     'ndax',
     'okcoin',
